pyrlp
=====

A Python implementation of Recursive Length Prefix encoding (RLP). You can find
the specification of the standard in the
[Ethereum wiki](https://github.com/ethereum/wiki/wiki/RLP) and the
documentation of this package on
[readthedocs](http://pyrlp.readthedocs.org/en/latest/).
